import os
import platform

system = platform.system()

paths = {
    'Windows': {
        'downloads': os.path.expanduser('~/Downloads'),
        'movies': os.path.expanduser('~/Videos/Movies'),
        'series': os.path.expanduser('~/Videos/Series'),
        'config': os.path.expanduser('~/.linuxserver'),
        'docker': os.path.expanduser('~/.linuxserver/docker'),
    },
    'Linux': {
        'downloads': os.path.expanduser('~/Downloads'),
        'movies': os.path.expanduser('~/Movies/Movies'),
        'series': os.path.expanduser('~/Videos/Series'),
        'config': os.path.expanduser('~/.linuxserver'),
        'docker': os.path.expanduser('~/.linuxserver/docker'),
    },
    'Darwin': {
        'downloads': os.path.expanduser('~/Downloads'),
        'movies': os.path.expanduser('~/Movies/Movies'),
        'series': os.path.expanduser('~/Movies/Series'),
        'config': os.path.expanduser('~/linuxserver'),
        'docker': os.path.expanduser('~/linuxserver/docker'),
    },
}

services = {
    'deluge': {
        'paths': {
            'downloads': paths[system]['downloads'],
            'docker': os.path.join(paths[system]['docker'], 'deluge'),
            'config': os.path.join(paths[system]['config'], 'deluge'),
        },
    },
    'gluetun': {
        'paths': {
            'docker': os.path.join(paths[system]['docker'], 'gluetun'),
            'config': os.path.join(paths[system]['config'], 'gluetun'),
        }
    },
    'jackett': {
        'paths': {
            'downloads': paths[system]['downloads'],
            'docker': os.path.join(paths[system]['docker'], 'jackett'),
            'config': os.path.join(paths[system]['config'], 'jackett'),
        },
    },
    'plex': {
        'paths': {
            'downloads': paths[system]['downloads'],
            'movies': paths[system]['movies'],
            'series': paths[system]['series'],
            'docker': os.path.join(paths[system]['docker'], 'plex'),
            'config': os.path.join(paths[system]['config'], 'plex'),
        },
    },
    'radarr': {
        'paths': {
            'downloads': paths[system]['downloads'],
            'movies': paths[system]['movies'],
            'docker': os.path.join(paths[system]['docker'], 'radarr'),
            'radarr': os.path.join(paths[system]['config'], 'radarr'),
            'config': os.path.join(paths[system]['config'], 'radarr'),
        },
    },
    'sonarr': {
        'paths': {
            'downloads': paths[system]['downloads'],
            'series': paths[system]['series'],
            'docker': os.path.join(paths[system]['docker'], 'sonarr'),
            'config': os.path.join(paths[system]['config'], 'sonarr'),
        },
    },
}



from jinja2 import Template
from version import __version__
from . import config
import argparse
import os
import subprocess


SYSTEM = config.system
SERVICES = config.services.keys()
PATHS = config.paths
ROOT = os.path.dirname(__file__)
DOWNLOADS = PATHS[SYSTEM]['downloads']
MOVIES = PATHS[SYSTEM]['movies']
SERIES = PATHS[SYSTEM]['series']
DOCKER = PATHS[SYSTEM]['docker']
CONFIG = PATHS[SYSTEM]['docker']


def main():

    parser = argparse.ArgumentParser()
    parser.add_argument(
        '-v',
        '--version',
        action='version',
        version=__version__
    )
    subparsers = parser.add_subparsers()

    deploy = subparsers.add_parser('deploy')
    deploy.add_argument('services', nargs='+', choices=SERVICES)
    deploy.add_argument('--downloads-path', type=str, default=DOWNLOADS)
    deploy.add_argument('--movies-path', type=str, default=MOVIES)
    deploy.add_argument('--series-path', type=str, default=SERIES)
    deploy.add_argument('--docker-path', type=str, default=DOCKER)
    deploy.add_argument('--config-path', type=str, default=CONFIG)

    args = parser.parse_args()

    for service in args.services:

        # Get service paths
        service_paths = config.services[service]['paths']

        # Create directories
        create_directories(service_paths)

        # Get docker path
        docker_path = os.path.join(
            config.paths[SYSTEM]['docker'], service, f'{service}-compose.yml'
        )

        # Copy .yml files
        copy_docker_yml(service, ROOT, docker_path)

        # Run docker
        validate_docker_installation()
        run_docker_yml(service, docker_path)


def validate_docker_installation():
    try:
        subprocess.call('docker version', shell=True)
    except Exception:
        print('Please install Docker CLI')
        quit()


def create_directories(paths):

    for path in paths.values():
        if not os.path.exists(path):
            os.makedirs(path)


def copy_docker_yml(service, src, dst):

    src = f'{src}/docker/{service}-compose.yml'

    with open(src, 'r') as source, open(dst, 'w+') as destination:
        template = Template(source.read())
        render = template.render(config.services[service]['paths'])
        destination.write(render)


def run_docker_yml(service, dst):
    cmd = f'docker-compose -f {dst} up -d'
    subprocess.call(cmd, shell=True)


if __name__ == '__main__':
    main()



from version import __version__
from setuptools import setup


with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

setup(
    name='linuxserver',
    version=__version__,
    description='A simple CLI to deploy linuxserver services',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Frank Oprel',
    author_email='fj.oprel@gmail.com',
    url='https://github.com/foprel/linuxserver',
    install_requires=requirements,
    license=license,
    packages=[
        '.',
        'cli'
    ],
    package_dir={'cli': 'src/cli'},
    include_package_data=True,
    entry_points={
        'console_scripts': ['linuxserver = cli.cli:main'],
    },
    python_requires='>=3.8',
)
